# Firefly III API Client
This is the Python client for Firefly III API

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.5
- Package version: 2.0.5.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://firefly-iii.org](https://firefly-iii.org)

## Requirements.

Python &gt;&#x3D;3.7

## Migration from other generators like python and python-legacy

### Changes
1. This generator uses spec case for all (object) property names and parameter names.
    - So if the spec has a property name like camelCase, it will use camelCase rather than camel_case
    - So you will need to update how you input and read properties to use spec case
2. Endpoint parameters are stored in dictionaries to prevent collisions (explanation below)
    - So you will need to update how you pass data in to endpoints
3. Endpoint responses now include the original response, the deserialized response body, and (todo)the deserialized headers
    - So you will need to update your code to use response.body to access deserialized data
4. All validated data is instantiated in an instance that subclasses all validated Schema classes and Decimal/str/list/tuple/frozendict/NoneClass/BoolClass/bytes/io.FileIO
    - This means that you can use isinstance to check if a payload validated against a schema class
    - This means that no data will be of type None/True/False
        - ingested None will subclass NoneClass
        - ingested True will subclass BoolClass
        - ingested False will subclass BoolClass
        - So if you need to check is True/False/None, instead use instance.is_true_oapg()/.is_false_oapg()/.is_none_oapg()
5. All validated class instances are immutable except for ones based on io.File
    - This is because if properties were changed after validation, that validation would no longer apply
    - So no changing values or property values after a class has been instantiated
6. String + Number types with formats
    - String type data is stored as a string and if you need to access types based on its format like date,
    date-time, uuid, number etc then you will need to use accessor functions on the instance
    - type string + format: See .as_date_oapg, .as_datetime_oapg, .as_decimal_oapg, .as_uuid_oapg
    - type number + format: See .as_float_oapg, .as_int_oapg
    - this was done because openapi/json-schema defines constraints. string data may be type string with no format
    keyword in one schema, and include a format constraint in another schema
    - So if you need to access a string format based type, use as_date_oapg/as_datetime_oapg/as_decimal_oapg/as_uuid_oapg
    - So if you need to access a number format based type, use as_int_oapg/as_float_oapg
7. Property access on AnyType(type unset) or object(dict) schemas
    - Only required keys with valid python names are properties like .someProp and have type hints
    - All optional keys may not exist, so properties are not defined for them
    - One can access optional values with dict_instance['optionalProp'] and KeyError will be raised if it does not exist
    - Use get_item_oapg if you need a way to always get a value whether or not the key exists
        - If the key does not exist, schemas.unset is returned from calling dict_instance.get_item_oapg('optionalProp')
        - All required and optional keys have type hints for this method, and @typing.overload is used
        - A type hint is also generated for additionalProperties accessed using this method
    - So you will need to update you code to use some_instance['optionalProp'] to access optional property
    and additionalProperty values
8. The location of the api classes has changed
    - Api classes are located in your_package.apis.tags.some_api
    - This change was made to eliminate redundant code generation
    - Legacy generators generated the same endpoint twice if it had > 1 tag on it
    - This generator defines an endpoint in one class, then inherits that class to generate
      apis by tags and by paths
    - This change reduces code and allows quicker run time if you use the path apis
        - path apis are at your_package.apis.paths.some_path
    - Those apis will only load their needed models, which is less to load than all of the resources needed in a tag api
    - So you will need to update your import paths to the api classes

### Why are Oapg and _oapg used in class and method names?
Classes can have arbitrarily named properties set on them
Endpoints can have arbitrary operationId method names set
For those reasons, I use the prefix Oapg and _oapg to greatly reduce the likelihood of collisions
on protected + public classes/methods.
oapg stands for OpenApi Python Generator.

### Object property spec case
This was done because when payloads are ingested, they can be validated against N number of schemas.
If the input signature used a different property name then that has mutated the payload.
So SchemaA and SchemaB must both see the camelCase spec named variable.
Also it is possible to send in two properties, named camelCase and camel_case in the same payload.
That use case should be support so spec case is used.

### Parameter spec case
Parameters can be included in different locations including:
- query
- path
- header
- cookie

Any of those parameters could use the same parameter names, so if every parameter
was included as an endpoint parameter in a function signature, they would collide.
For that reason, each of those inputs have been separated out into separate typed dictionaries:
- query_params
- path_params
- header_params
- cookie_params

So when updating your code, you will need to pass endpoint parameters in using those
dictionaries.

### Endpoint responses
Endpoint responses have been enriched to now include more information.
Any response reom an endpoint will now include the following properties:
response: urllib3.HTTPResponse
body: typing.Union[Unset, Schema]
headers: typing.Union[Unset, TODO]
Note: response header deserialization has not yet been added


## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install Firefly-III-API-Client
```
(you may need to run `pip` with root permission: `sudo pip install Firefly-III-API-Client`)

Then import the package:
```python
import firefly_iii_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import firefly_iii_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import firefly_iii_client
from pprint import pprint
from firefly_iii_client.apis.tags import about_api
from firefly_iii_client.model.bad_request import BadRequest
from firefly_iii_client.model.cron_result import CronResult
from firefly_iii_client.model.internal_exception import InternalException
from firefly_iii_client.model.not_found import NotFound
from firefly_iii_client.model.system_info import SystemInfo
from firefly_iii_client.model.unauthenticated import Unauthenticated
from firefly_iii_client.model.user_single import UserSingle
# Defining the host is optional and defaults to https://demo.firefly-iii.org/api
# See configuration.py for a list of all supported configuration parameters.
configuration = firefly_iii_client.Configuration(
    host = "https://demo.firefly-iii.org/api"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure OAuth2 access token for authorization: firefly_iii_auth
configuration = firefly_iii_client.Configuration(
    host = "https://demo.firefly-iii.org/api",
    access_token = 'YOUR_ACCESS_TOKEN'
)

# Enter a context with an instance of the API client
with firefly_iii_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = about_api.AboutApi(api_client)
    x_trace_id = "X-Trace-Id_example" # str | Unique identifier associated with this request. (optional)

    try:
        # System information end point.
        api_response = api_instance.get_about(x_trace_id=x_trace_id)
        pprint(api_response)
    except firefly_iii_client.ApiException as e:
        print("Exception when calling AboutApi->get_about: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://demo.firefly-iii.org/api*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AboutApi* | [**get_about**](docs/apis/tags/AboutApi.md#get_about) | **get** /v1/about | System information end point.
*AboutApi* | [**get_cron**](docs/apis/tags/AboutApi.md#get_cron) | **get** /v1/cron/{cliToken} | Cron job endpoint
*AboutApi* | [**get_current_user**](docs/apis/tags/AboutApi.md#get_current_user) | **get** /v1/about/user | Currently authenticated user endpoint.
*AccountsApi* | [**delete_account**](docs/apis/tags/AccountsApi.md#delete_account) | **delete** /v1/accounts/{id} | Permanently delete account.
*AccountsApi* | [**get_account**](docs/apis/tags/AccountsApi.md#get_account) | **get** /v1/accounts/{id} | Get single account.
*AccountsApi* | [**list_account**](docs/apis/tags/AccountsApi.md#list_account) | **get** /v1/accounts | List all accounts.
*AccountsApi* | [**list_attachment_by_account**](docs/apis/tags/AccountsApi.md#list_attachment_by_account) | **get** /v1/accounts/{id}/attachments | Lists all attachments.
*AccountsApi* | [**list_piggy_bank_by_account**](docs/apis/tags/AccountsApi.md#list_piggy_bank_by_account) | **get** /v1/accounts/{id}/piggy-banks | List all piggy banks related to the account.
*AccountsApi* | [**list_transaction_by_account**](docs/apis/tags/AccountsApi.md#list_transaction_by_account) | **get** /v1/accounts/{id}/transactions | List all transactions related to the account.
*AccountsApi* | [**store_account**](docs/apis/tags/AccountsApi.md#store_account) | **post** /v1/accounts | Create new account.
*AccountsApi* | [**update_account**](docs/apis/tags/AccountsApi.md#update_account) | **put** /v1/accounts/{id} | Update existing account.
*AttachmentsApi* | [**delete_attachment**](docs/apis/tags/AttachmentsApi.md#delete_attachment) | **delete** /v1/attachments/{id} | Delete an attachment.
*AttachmentsApi* | [**download_attachment**](docs/apis/tags/AttachmentsApi.md#download_attachment) | **get** /v1/attachments/{id}/download | Download a single attachment.
*AttachmentsApi* | [**get_attachment**](docs/apis/tags/AttachmentsApi.md#get_attachment) | **get** /v1/attachments/{id} | Get a single attachment.
*AttachmentsApi* | [**list_attachment**](docs/apis/tags/AttachmentsApi.md#list_attachment) | **get** /v1/attachments | List all attachments.
*AttachmentsApi* | [**store_attachment**](docs/apis/tags/AttachmentsApi.md#store_attachment) | **post** /v1/attachments | Store a new attachment.
*AttachmentsApi* | [**update_attachment**](docs/apis/tags/AttachmentsApi.md#update_attachment) | **put** /v1/attachments/{id} | Update existing attachment.
*AttachmentsApi* | [**upload_attachment**](docs/apis/tags/AttachmentsApi.md#upload_attachment) | **post** /v1/attachments/{id}/upload | Upload an attachment.
*AutocompleteApi* | [**get_accounts_ac**](docs/apis/tags/AutocompleteApi.md#get_accounts_ac) | **get** /v1/autocomplete/accounts | Returns all accounts of the user returned in a basic auto-complete array.
*AutocompleteApi* | [**get_bills_ac**](docs/apis/tags/AutocompleteApi.md#get_bills_ac) | **get** /v1/autocomplete/bills | Returns all bills of the user returned in a basic auto-complete array.
*AutocompleteApi* | [**get_budgets_ac**](docs/apis/tags/AutocompleteApi.md#get_budgets_ac) | **get** /v1/autocomplete/budgets | Returns all budgets of the user returned in a basic auto-complete array.
*AutocompleteApi* | [**get_categories_ac**](docs/apis/tags/AutocompleteApi.md#get_categories_ac) | **get** /v1/autocomplete/categories | Returns all categories of the user returned in a basic auto-complete array.
*AutocompleteApi* | [**get_currencies_ac**](docs/apis/tags/AutocompleteApi.md#get_currencies_ac) | **get** /v1/autocomplete/currencies | Returns all currencies of the user returned in a basic auto-complete array.
*AutocompleteApi* | [**get_currencies_code_ac**](docs/apis/tags/AutocompleteApi.md#get_currencies_code_ac) | **get** /v1/autocomplete/currencies-with-code | Returns all currencies of the user returned in a basic auto-complete array. This endpoint is DEPRECATED and I suggest you DO NOT use it.
*AutocompleteApi* | [**get_object_groups_ac**](docs/apis/tags/AutocompleteApi.md#get_object_groups_ac) | **get** /v1/autocomplete/object-groups | Returns all object groups of the user returned in a basic auto-complete array.
*AutocompleteApi* | [**get_piggies_ac**](docs/apis/tags/AutocompleteApi.md#get_piggies_ac) | **get** /v1/autocomplete/piggy-banks | Returns all piggy banks of the user returned in a basic auto-complete array.
*AutocompleteApi* | [**get_piggies_balance_ac**](docs/apis/tags/AutocompleteApi.md#get_piggies_balance_ac) | **get** /v1/autocomplete/piggy-banks-with-balance | Returns all piggy banks of the user returned in a basic auto-complete array complemented with balance information.
*AutocompleteApi* | [**get_recurring_ac**](docs/apis/tags/AutocompleteApi.md#get_recurring_ac) | **get** /v1/autocomplete/recurring | Returns all recurring transactions of the user returned in a basic auto-complete array.
*AutocompleteApi* | [**get_rule_groups_ac**](docs/apis/tags/AutocompleteApi.md#get_rule_groups_ac) | **get** /v1/autocomplete/rule-groups | Returns all rule groups of the user returned in a basic auto-complete array.
*AutocompleteApi* | [**get_rules_ac**](docs/apis/tags/AutocompleteApi.md#get_rules_ac) | **get** /v1/autocomplete/rules | Returns all rules of the user returned in a basic auto-complete array.
*AutocompleteApi* | [**get_tag_ac**](docs/apis/tags/AutocompleteApi.md#get_tag_ac) | **get** /v1/autocomplete/tags | Returns all tags of the user returned in a basic auto-complete array.
*AutocompleteApi* | [**get_transaction_types_ac**](docs/apis/tags/AutocompleteApi.md#get_transaction_types_ac) | **get** /v1/autocomplete/transaction-types | Returns all transaction types returned in a basic auto-complete array. English only.
*AutocompleteApi* | [**get_transactions_ac**](docs/apis/tags/AutocompleteApi.md#get_transactions_ac) | **get** /v1/autocomplete/transactions | Returns all transaction descriptions of the user returned in a basic auto-complete array.
*AutocompleteApi* | [**get_transactions_idac**](docs/apis/tags/AutocompleteApi.md#get_transactions_idac) | **get** /v1/autocomplete/transactions-with-id | Returns all transactions, complemented with their ID, of the user returned in a basic auto-complete array. This endpoint is DEPRECATED and I suggest you DO NOT use it.
*AvailableBudgetsApi* | [**get_available_budget**](docs/apis/tags/AvailableBudgetsApi.md#get_available_budget) | **get** /v1/available-budgets/{id} | Get a single available budget.
*AvailableBudgetsApi* | [**list_available_budget**](docs/apis/tags/AvailableBudgetsApi.md#list_available_budget) | **get** /v1/available-budgets | List all available budget amounts.
*BillsApi* | [**delete_bill**](docs/apis/tags/BillsApi.md#delete_bill) | **delete** /v1/bills/{id} | Delete a bill.
*BillsApi* | [**get_bill**](docs/apis/tags/BillsApi.md#get_bill) | **get** /v1/bills/{id} | Get a single bill.
*BillsApi* | [**list_attachment_by_bill**](docs/apis/tags/BillsApi.md#list_attachment_by_bill) | **get** /v1/bills/{id}/attachments | List all attachments uploaded to the bill.
*BillsApi* | [**list_bill**](docs/apis/tags/BillsApi.md#list_bill) | **get** /v1/bills | List all bills.
*BillsApi* | [**list_rule_by_bill**](docs/apis/tags/BillsApi.md#list_rule_by_bill) | **get** /v1/bills/{id}/rules | List all rules associated with the bill.
*BillsApi* | [**list_transaction_by_bill**](docs/apis/tags/BillsApi.md#list_transaction_by_bill) | **get** /v1/bills/{id}/transactions | List all transactions associated with the  bill.
*BillsApi* | [**store_bill**](docs/apis/tags/BillsApi.md#store_bill) | **post** /v1/bills | Store a new bill
*BillsApi* | [**update_bill**](docs/apis/tags/BillsApi.md#update_bill) | **put** /v1/bills/{id} | Update existing bill.
*BudgetsApi* | [**delete_budget**](docs/apis/tags/BudgetsApi.md#delete_budget) | **delete** /v1/budgets/{id} | Delete a budget.
*BudgetsApi* | [**delete_budget_limit**](docs/apis/tags/BudgetsApi.md#delete_budget_limit) | **delete** /v1/budgets/{id}/limits/{limitId} | Delete a budget limit.
*BudgetsApi* | [**get_budget**](docs/apis/tags/BudgetsApi.md#get_budget) | **get** /v1/budgets/{id} | Get a single budget.
*BudgetsApi* | [**get_budget_limit**](docs/apis/tags/BudgetsApi.md#get_budget_limit) | **get** /v1/budgets/{id}/limits/{limitId} | Get single budget limit.
*BudgetsApi* | [**list_attachment_by_budget**](docs/apis/tags/BudgetsApi.md#list_attachment_by_budget) | **get** /v1/budgets/{id}/attachments | Lists all attachments of a budget.
*BudgetsApi* | [**list_budget**](docs/apis/tags/BudgetsApi.md#list_budget) | **get** /v1/budgets | List all budgets.
*BudgetsApi* | [**list_budget_limit**](docs/apis/tags/BudgetsApi.md#list_budget_limit) | **get** /v1/budget-limits | Get list of budget limits by date
*BudgetsApi* | [**list_budget_limit_by_budget**](docs/apis/tags/BudgetsApi.md#list_budget_limit_by_budget) | **get** /v1/budgets/{id}/limits | Get all limits for a budget.
*BudgetsApi* | [**list_transaction_by_budget**](docs/apis/tags/BudgetsApi.md#list_transaction_by_budget) | **get** /v1/budgets/{id}/transactions | All transactions to a budget.
*BudgetsApi* | [**list_transaction_by_budget_limit**](docs/apis/tags/BudgetsApi.md#list_transaction_by_budget_limit) | **get** /v1/budgets/{id}/limits/{limitId}/transactions | List all transactions by a budget limit ID.
*BudgetsApi* | [**store_budget**](docs/apis/tags/BudgetsApi.md#store_budget) | **post** /v1/budgets | Store a new budget
*BudgetsApi* | [**store_budget_limit**](docs/apis/tags/BudgetsApi.md#store_budget_limit) | **post** /v1/budgets/{id}/limits | Store new budget limit.
*BudgetsApi* | [**update_budget**](docs/apis/tags/BudgetsApi.md#update_budget) | **put** /v1/budgets/{id} | Update existing budget.
*BudgetsApi* | [**update_budget_limit**](docs/apis/tags/BudgetsApi.md#update_budget_limit) | **put** /v1/budgets/{id}/limits/{limitId} | Update existing budget limit.
*CategoriesApi* | [**delete_category**](docs/apis/tags/CategoriesApi.md#delete_category) | **delete** /v1/categories/{id} | Delete a category.
*CategoriesApi* | [**get_category**](docs/apis/tags/CategoriesApi.md#get_category) | **get** /v1/categories/{id} | Get a single category.
*CategoriesApi* | [**list_attachment_by_category**](docs/apis/tags/CategoriesApi.md#list_attachment_by_category) | **get** /v1/categories/{id}/attachments | Lists all attachments.
*CategoriesApi* | [**list_category**](docs/apis/tags/CategoriesApi.md#list_category) | **get** /v1/categories | List all categories.
*CategoriesApi* | [**list_transaction_by_category**](docs/apis/tags/CategoriesApi.md#list_transaction_by_category) | **get** /v1/categories/{id}/transactions | List all transactions in a category.
*CategoriesApi* | [**store_category**](docs/apis/tags/CategoriesApi.md#store_category) | **post** /v1/categories | Store a new category
*CategoriesApi* | [**update_category**](docs/apis/tags/CategoriesApi.md#update_category) | **put** /v1/categories/{id} | Update existing category.
*ChartsApi* | [**get_chart_account_overview**](docs/apis/tags/ChartsApi.md#get_chart_account_overview) | **get** /v1/chart/account/overview | Dashboard chart with asset account balance information.
*ConfigurationApi* | [**get_configuration**](docs/apis/tags/ConfigurationApi.md#get_configuration) | **get** /v1/configuration | Get Firefly III system configuration values.
*ConfigurationApi* | [**get_single_configuration**](docs/apis/tags/ConfigurationApi.md#get_single_configuration) | **get** /v1/configuration/{name} | Get a single Firefly III system configuration value
*ConfigurationApi* | [**set_configuration**](docs/apis/tags/ConfigurationApi.md#set_configuration) | **put** /v1/configuration/{name} | Update configuration value
*CurrenciesApi* | [**default_currency**](docs/apis/tags/CurrenciesApi.md#default_currency) | **post** /v1/currencies/{code}/default | Make currency default currency.
*CurrenciesApi* | [**delete_currency**](docs/apis/tags/CurrenciesApi.md#delete_currency) | **delete** /v1/currencies/{code} | Delete a currency.
*CurrenciesApi* | [**disable_currency**](docs/apis/tags/CurrenciesApi.md#disable_currency) | **post** /v1/currencies/{code}/disable | Disable a currency.
*CurrenciesApi* | [**enable_currency**](docs/apis/tags/CurrenciesApi.md#enable_currency) | **post** /v1/currencies/{code}/enable | Enable a single currency.
*CurrenciesApi* | [**get_currency**](docs/apis/tags/CurrenciesApi.md#get_currency) | **get** /v1/currencies/{code} | Get a single currency.
*CurrenciesApi* | [**get_default_currency**](docs/apis/tags/CurrenciesApi.md#get_default_currency) | **get** /v1/currencies/default | Get the user&#x27;s default currency.
*CurrenciesApi* | [**list_account_by_currency**](docs/apis/tags/CurrenciesApi.md#list_account_by_currency) | **get** /v1/currencies/{code}/accounts | List all accounts with this currency.
*CurrenciesApi* | [**list_available_budget_by_currency**](docs/apis/tags/CurrenciesApi.md#list_available_budget_by_currency) | **get** /v1/currencies/{code}/available-budgets | List all available budgets with this currency.
*CurrenciesApi* | [**list_bill_by_currency**](docs/apis/tags/CurrenciesApi.md#list_bill_by_currency) | **get** /v1/currencies/{code}/bills | List all bills with this currency.
*CurrenciesApi* | [**list_budget_limit_by_currency**](docs/apis/tags/CurrenciesApi.md#list_budget_limit_by_currency) | **get** /v1/currencies/{code}/budget_limits | List all budget limits with this currency
*CurrenciesApi* | [**list_currency**](docs/apis/tags/CurrenciesApi.md#list_currency) | **get** /v1/currencies | List all currencies.
*CurrenciesApi* | [**list_recurrence_by_currency**](docs/apis/tags/CurrenciesApi.md#list_recurrence_by_currency) | **get** /v1/currencies/{code}/recurrences | List all recurring transactions with this currency.
*CurrenciesApi* | [**list_rule_by_currency**](docs/apis/tags/CurrenciesApi.md#list_rule_by_currency) | **get** /v1/currencies/{code}/rules | List all rules with this currency.
*CurrenciesApi* | [**list_transaction_by_currency**](docs/apis/tags/CurrenciesApi.md#list_transaction_by_currency) | **get** /v1/currencies/{code}/transactions | List all transactions with this currency.
*CurrenciesApi* | [**store_currency**](docs/apis/tags/CurrenciesApi.md#store_currency) | **post** /v1/currencies | Store a new currency
*CurrenciesApi* | [**update_currency**](docs/apis/tags/CurrenciesApi.md#update_currency) | **put** /v1/currencies/{code} | Update existing currency.
*DataApi* | [**bulk_update_transactions**](docs/apis/tags/DataApi.md#bulk_update_transactions) | **post** /v1/data/bulk/transactions | Bulk update transaction properties. For more information, see https://docs.firefly-iii.org/firefly-iii/api/specials
*DataApi* | [**destroy_data**](docs/apis/tags/DataApi.md#destroy_data) | **delete** /v1/data/destroy | Endpoint to destroy user data
*DataApi* | [**export_accounts**](docs/apis/tags/DataApi.md#export_accounts) | **get** /v1/data/export/accounts | Export account data from Firefly III
*DataApi* | [**export_bills**](docs/apis/tags/DataApi.md#export_bills) | **get** /v1/data/export/bills | Export bills from Firefly III
*DataApi* | [**export_budgets**](docs/apis/tags/DataApi.md#export_budgets) | **get** /v1/data/export/budgets | Export budgets and budget amount data from Firefly III
*DataApi* | [**export_categories**](docs/apis/tags/DataApi.md#export_categories) | **get** /v1/data/export/categories | Export category data from Firefly III
*DataApi* | [**export_piggies**](docs/apis/tags/DataApi.md#export_piggies) | **get** /v1/data/export/piggy-banks | Export piggy banks from Firefly III
*DataApi* | [**export_recurring**](docs/apis/tags/DataApi.md#export_recurring) | **get** /v1/data/export/recurring | Export recurring transaction data from Firefly III
*DataApi* | [**export_rules**](docs/apis/tags/DataApi.md#export_rules) | **get** /v1/data/export/rules | Export rule groups and rule data from Firefly III
*DataApi* | [**export_tags**](docs/apis/tags/DataApi.md#export_tags) | **get** /v1/data/export/tags | Export tag data from Firefly III
*DataApi* | [**export_transactions**](docs/apis/tags/DataApi.md#export_transactions) | **get** /v1/data/export/transactions | Export transaction data from Firefly III
*DataApi* | [**purge_data**](docs/apis/tags/DataApi.md#purge_data) | **delete** /v1/data/purge | Endpoint to purge user data
*InsightApi* | [**insight_expense_asset**](docs/apis/tags/InsightApi.md#insight_expense_asset) | **get** /v1/insight/expense/asset | Insight into expenses, grouped by asset account.
*InsightApi* | [**insight_expense_bill**](docs/apis/tags/InsightApi.md#insight_expense_bill) | **get** /v1/insight/expense/bill | Insight into expenses, grouped by bill.
*InsightApi* | [**insight_expense_budget**](docs/apis/tags/InsightApi.md#insight_expense_budget) | **get** /v1/insight/expense/budget | Insight into expenses, grouped by budget.
*InsightApi* | [**insight_expense_category**](docs/apis/tags/InsightApi.md#insight_expense_category) | **get** /v1/insight/expense/category | Insight into expenses, grouped by category.
*InsightApi* | [**insight_expense_expense**](docs/apis/tags/InsightApi.md#insight_expense_expense) | **get** /v1/insight/expense/expense | Insight into expenses, grouped by expense account.
*InsightApi* | [**insight_expense_no_bill**](docs/apis/tags/InsightApi.md#insight_expense_no_bill) | **get** /v1/insight/expense/no-bill | Insight into expenses, without bill.
*InsightApi* | [**insight_expense_no_budget**](docs/apis/tags/InsightApi.md#insight_expense_no_budget) | **get** /v1/insight/expense/no-budget | Insight into expenses, without budget.
*InsightApi* | [**insight_expense_no_category**](docs/apis/tags/InsightApi.md#insight_expense_no_category) | **get** /v1/insight/expense/no-category | Insight into expenses, without category.
*InsightApi* | [**insight_expense_no_tag**](docs/apis/tags/InsightApi.md#insight_expense_no_tag) | **get** /v1/insight/expense/no-tag | Insight into expenses, without tag.
*InsightApi* | [**insight_expense_tag**](docs/apis/tags/InsightApi.md#insight_expense_tag) | **get** /v1/insight/expense/tag | Insight into expenses, grouped by tag.
*InsightApi* | [**insight_expense_total**](docs/apis/tags/InsightApi.md#insight_expense_total) | **get** /v1/insight/expense/total | Insight into total expenses.
*InsightApi* | [**insight_income_asset**](docs/apis/tags/InsightApi.md#insight_income_asset) | **get** /v1/insight/income/asset | Insight into income, grouped by asset account.
*InsightApi* | [**insight_income_category**](docs/apis/tags/InsightApi.md#insight_income_category) | **get** /v1/insight/income/category | Insight into income, grouped by category.
*InsightApi* | [**insight_income_no_category**](docs/apis/tags/InsightApi.md#insight_income_no_category) | **get** /v1/insight/income/no-category | Insight into income, without category.
*InsightApi* | [**insight_income_no_tag**](docs/apis/tags/InsightApi.md#insight_income_no_tag) | **get** /v1/insight/income/no-tag | Insight into income, without tag.
*InsightApi* | [**insight_income_revenue**](docs/apis/tags/InsightApi.md#insight_income_revenue) | **get** /v1/insight/income/revenue | Insight into income, grouped by revenue account.
*InsightApi* | [**insight_income_tag**](docs/apis/tags/InsightApi.md#insight_income_tag) | **get** /v1/insight/income/tag | Insight into income, grouped by tag.
*InsightApi* | [**insight_income_total**](docs/apis/tags/InsightApi.md#insight_income_total) | **get** /v1/insight/income/total | Insight into total income.
*InsightApi* | [**insight_transfer_category**](docs/apis/tags/InsightApi.md#insight_transfer_category) | **get** /v1/insight/transfer/category | Insight into transfers, grouped by category.
*InsightApi* | [**insight_transfer_no_category**](docs/apis/tags/InsightApi.md#insight_transfer_no_category) | **get** /v1/insight/transfer/no-category | Insight into transfers, without category.
*InsightApi* | [**insight_transfer_no_tag**](docs/apis/tags/InsightApi.md#insight_transfer_no_tag) | **get** /v1/insight/transfer/no-tag | Insight into expenses, without tag.
*InsightApi* | [**insight_transfer_tag**](docs/apis/tags/InsightApi.md#insight_transfer_tag) | **get** /v1/insight/transfer/tag | Insight into transfers, grouped by tag.
*InsightApi* | [**insight_transfer_total**](docs/apis/tags/InsightApi.md#insight_transfer_total) | **get** /v1/insight/transfer/total | Insight into total transfers.
*InsightApi* | [**insight_transfers**](docs/apis/tags/InsightApi.md#insight_transfers) | **get** /v1/insight/transfer/asset | Insight into transfers, grouped by account.
*LinksApi* | [**delete_link_type**](docs/apis/tags/LinksApi.md#delete_link_type) | **delete** /v1/link-types/{id} | Permanently delete link type.
*LinksApi* | [**delete_transaction_link**](docs/apis/tags/LinksApi.md#delete_transaction_link) | **delete** /v1/transaction-links/{id} | Permanently delete link between transactions.
*LinksApi* | [**get_link_type**](docs/apis/tags/LinksApi.md#get_link_type) | **get** /v1/link-types/{id} | Get single a link type.
*LinksApi* | [**get_transaction_link**](docs/apis/tags/LinksApi.md#get_transaction_link) | **get** /v1/transaction-links/{id} | Get a single link.
*LinksApi* | [**list_link_type**](docs/apis/tags/LinksApi.md#list_link_type) | **get** /v1/link-types | List all types of links.
*LinksApi* | [**list_transaction_by_link_type**](docs/apis/tags/LinksApi.md#list_transaction_by_link_type) | **get** /v1/link-types/{id}/transactions | List all transactions under this link type.
*LinksApi* | [**list_transaction_link**](docs/apis/tags/LinksApi.md#list_transaction_link) | **get** /v1/transaction-links | List all transaction links.
*LinksApi* | [**store_link_type**](docs/apis/tags/LinksApi.md#store_link_type) | **post** /v1/link-types | Create a new link type
*LinksApi* | [**store_transaction_link**](docs/apis/tags/LinksApi.md#store_transaction_link) | **post** /v1/transaction-links | Create a new link between transactions
*LinksApi* | [**update_link_type**](docs/apis/tags/LinksApi.md#update_link_type) | **put** /v1/link-types/{id} | Update existing link type.
*LinksApi* | [**update_transaction_link**](docs/apis/tags/LinksApi.md#update_transaction_link) | **put** /v1/transaction-links/{id} | Update an existing link between transactions.
*ObjectGroupsApi* | [**delete_object_group**](docs/apis/tags/ObjectGroupsApi.md#delete_object_group) | **delete** /v1/object-groups/{id} | Delete a object group.
*ObjectGroupsApi* | [**get_object_group**](docs/apis/tags/ObjectGroupsApi.md#get_object_group) | **get** /v1/object-groups/{id} | Get a single object group.
*ObjectGroupsApi* | [**list_bill_by_object_group**](docs/apis/tags/ObjectGroupsApi.md#list_bill_by_object_group) | **get** /v1/object-groups/{id}/bills | List all bills with this object group.
*ObjectGroupsApi* | [**list_object_groups**](docs/apis/tags/ObjectGroupsApi.md#list_object_groups) | **get** /v1/object-groups | List all oject groups.
*ObjectGroupsApi* | [**list_piggy_bank_by_object_group**](docs/apis/tags/ObjectGroupsApi.md#list_piggy_bank_by_object_group) | **get** /v1/object-groups/{id}/piggy-banks | List all piggy banks related to the object group.
*ObjectGroupsApi* | [**update_object_group**](docs/apis/tags/ObjectGroupsApi.md#update_object_group) | **put** /v1/object-groups/{id} | Update existing object group.
*PiggyBanksApi* | [**delete_piggy_bank**](docs/apis/tags/PiggyBanksApi.md#delete_piggy_bank) | **delete** /v1/piggy-banks/{id} | Delete a piggy bank.
*PiggyBanksApi* | [**get_piggy_bank**](docs/apis/tags/PiggyBanksApi.md#get_piggy_bank) | **get** /v1/piggy-banks/{id} | Get a single piggy bank.
*PiggyBanksApi* | [**list_attachment_by_piggy_bank**](docs/apis/tags/PiggyBanksApi.md#list_attachment_by_piggy_bank) | **get** /v1/piggy-banks/{id}/attachments | Lists all attachments.
*PiggyBanksApi* | [**list_event_by_piggy_bank**](docs/apis/tags/PiggyBanksApi.md#list_event_by_piggy_bank) | **get** /v1/piggy-banks/{id}/events | List all events linked to a piggy bank.
*PiggyBanksApi* | [**list_piggy_bank**](docs/apis/tags/PiggyBanksApi.md#list_piggy_bank) | **get** /v1/piggy-banks | List all piggy banks.
*PiggyBanksApi* | [**store_piggy_bank**](docs/apis/tags/PiggyBanksApi.md#store_piggy_bank) | **post** /v1/piggy-banks | Store a new piggy bank
*PiggyBanksApi* | [**update_piggy_bank**](docs/apis/tags/PiggyBanksApi.md#update_piggy_bank) | **put** /v1/piggy-banks/{id} | Update existing piggy bank.
*PreferencesApi* | [**get_preference**](docs/apis/tags/PreferencesApi.md#get_preference) | **get** /v1/preferences/{name} | Return a single preference.
*PreferencesApi* | [**list_preference**](docs/apis/tags/PreferencesApi.md#list_preference) | **get** /v1/preferences | List all users preferences.
*PreferencesApi* | [**store_preference**](docs/apis/tags/PreferencesApi.md#store_preference) | **post** /v1/preferences | Store a new preference for this user.
*PreferencesApi* | [**update_preference**](docs/apis/tags/PreferencesApi.md#update_preference) | **put** /v1/preferences/{name} | Update preference
*RecurrencesApi* | [**delete_recurrence**](docs/apis/tags/RecurrencesApi.md#delete_recurrence) | **delete** /v1/recurrences/{id} | Delete a recurring transaction.
*RecurrencesApi* | [**get_recurrence**](docs/apis/tags/RecurrencesApi.md#get_recurrence) | **get** /v1/recurrences/{id} | Get a single recurring transaction.
*RecurrencesApi* | [**list_recurrence**](docs/apis/tags/RecurrencesApi.md#list_recurrence) | **get** /v1/recurrences | List all recurring transactions.
*RecurrencesApi* | [**list_transaction_by_recurrence**](docs/apis/tags/RecurrencesApi.md#list_transaction_by_recurrence) | **get** /v1/recurrences/{id}/transactions | List all transactions created by a recurring transaction.
*RecurrencesApi* | [**store_recurrence**](docs/apis/tags/RecurrencesApi.md#store_recurrence) | **post** /v1/recurrences | Store a new recurring transaction
*RecurrencesApi* | [**update_recurrence**](docs/apis/tags/RecurrencesApi.md#update_recurrence) | **put** /v1/recurrences/{id} | Update existing recurring transaction.
*RuleGroupsApi* | [**delete_rule_group**](docs/apis/tags/RuleGroupsApi.md#delete_rule_group) | **delete** /v1/rule-groups/{id} | Delete a rule group.
*RuleGroupsApi* | [**fire_rule_group**](docs/apis/tags/RuleGroupsApi.md#fire_rule_group) | **post** /v1/rule-groups/{id}/trigger | Fire the rule group on your transactions.
*RuleGroupsApi* | [**get_rule_group**](docs/apis/tags/RuleGroupsApi.md#get_rule_group) | **get** /v1/rule-groups/{id} | Get a single rule group.
*RuleGroupsApi* | [**list_rule_by_group**](docs/apis/tags/RuleGroupsApi.md#list_rule_by_group) | **get** /v1/rule-groups/{id}/rules | List rules in this rule group.
*RuleGroupsApi* | [**list_rule_group**](docs/apis/tags/RuleGroupsApi.md#list_rule_group) | **get** /v1/rule-groups | List all rule groups.
*RuleGroupsApi* | [**store_rule_group**](docs/apis/tags/RuleGroupsApi.md#store_rule_group) | **post** /v1/rule-groups | Store a new rule group.
*RuleGroupsApi* | [**test_rule_group**](docs/apis/tags/RuleGroupsApi.md#test_rule_group) | **get** /v1/rule-groups/{id}/test | Test which transactions would be hit by the rule group. No changes will be made.
*RuleGroupsApi* | [**update_rule_group**](docs/apis/tags/RuleGroupsApi.md#update_rule_group) | **put** /v1/rule-groups/{id} | Update existing rule group.
*RulesApi* | [**delete_rule**](docs/apis/tags/RulesApi.md#delete_rule) | **delete** /v1/rules/{id} | Delete an rule.
*RulesApi* | [**fire_rule**](docs/apis/tags/RulesApi.md#fire_rule) | **post** /v1/rules/{id}/trigger | Fire the rule on your transactions.
*RulesApi* | [**get_rule**](docs/apis/tags/RulesApi.md#get_rule) | **get** /v1/rules/{id} | Get a single rule.
*RulesApi* | [**list_rule**](docs/apis/tags/RulesApi.md#list_rule) | **get** /v1/rules | List all rules.
*RulesApi* | [**store_rule**](docs/apis/tags/RulesApi.md#store_rule) | **post** /v1/rules | Store a new rule
*RulesApi* | [**test_rule**](docs/apis/tags/RulesApi.md#test_rule) | **get** /v1/rules/{id}/test | Test which transactions would be hit by the rule. No changes will be made.
*RulesApi* | [**update_rule**](docs/apis/tags/RulesApi.md#update_rule) | **put** /v1/rules/{id} | Update existing rule.
*SearchApi* | [**search_accounts**](docs/apis/tags/SearchApi.md#search_accounts) | **get** /v1/search/accounts | Search for accounts
*SearchApi* | [**search_transactions**](docs/apis/tags/SearchApi.md#search_transactions) | **get** /v1/search/transactions | Search for transactions
*SummaryApi* | [**get_basic_summary**](docs/apis/tags/SummaryApi.md#get_basic_summary) | **get** /v1/summary/basic | Returns basic sums of the users data.
*TagsApi* | [**delete_tag**](docs/apis/tags/TagsApi.md#delete_tag) | **delete** /v1/tags/{tag} | Delete an tag.
*TagsApi* | [**get_tag**](docs/apis/tags/TagsApi.md#get_tag) | **get** /v1/tags/{tag} | Get a single tag.
*TagsApi* | [**list_attachment_by_tag**](docs/apis/tags/TagsApi.md#list_attachment_by_tag) | **get** /v1/tags/{tag}/attachments | Lists all attachments.
*TagsApi* | [**list_tag**](docs/apis/tags/TagsApi.md#list_tag) | **get** /v1/tags | List all tags.
*TagsApi* | [**list_transaction_by_tag**](docs/apis/tags/TagsApi.md#list_transaction_by_tag) | **get** /v1/tags/{tag}/transactions | List all transactions with this tag.
*TagsApi* | [**store_tag**](docs/apis/tags/TagsApi.md#store_tag) | **post** /v1/tags | Store a new tag
*TagsApi* | [**update_tag**](docs/apis/tags/TagsApi.md#update_tag) | **put** /v1/tags/{tag} | Update existing tag.
*TransactionsApi* | [**delete_transaction**](docs/apis/tags/TransactionsApi.md#delete_transaction) | **delete** /v1/transactions/{id} | Delete a transaction.
*TransactionsApi* | [**delete_transaction_journal**](docs/apis/tags/TransactionsApi.md#delete_transaction_journal) | **delete** /v1/transaction-journals/{id} | Delete split from transaction
*TransactionsApi* | [**get_transaction**](docs/apis/tags/TransactionsApi.md#get_transaction) | **get** /v1/transactions/{id} | Get a single transaction.
*TransactionsApi* | [**get_transaction_by_journal**](docs/apis/tags/TransactionsApi.md#get_transaction_by_journal) | **get** /v1/transaction-journals/{id} | Get a single transaction, based on one of the underlying transaction journals (transaction splits).
*TransactionsApi* | [**list_attachment_by_transaction**](docs/apis/tags/TransactionsApi.md#list_attachment_by_transaction) | **get** /v1/transactions/{id}/attachments | Lists all attachments.
*TransactionsApi* | [**list_event_by_transaction**](docs/apis/tags/TransactionsApi.md#list_event_by_transaction) | **get** /v1/transactions/{id}/piggy-bank-events | Lists all piggy bank events.
*TransactionsApi* | [**list_links_by_journal**](docs/apis/tags/TransactionsApi.md#list_links_by_journal) | **get** /v1/transaction-journals/{id}/links | Lists all the transaction links for an individual journal (individual split).
*TransactionsApi* | [**list_transaction**](docs/apis/tags/TransactionsApi.md#list_transaction) | **get** /v1/transactions | List all the user&#x27;s transactions. 
*TransactionsApi* | [**store_transaction**](docs/apis/tags/TransactionsApi.md#store_transaction) | **post** /v1/transactions | Store a new transaction
*TransactionsApi* | [**update_transaction**](docs/apis/tags/TransactionsApi.md#update_transaction) | **put** /v1/transactions/{id} | Update existing transaction. For more information, see https://docs.firefly-iii.org/firefly-iii/api/specials
*UsersApi* | [**delete_user**](docs/apis/tags/UsersApi.md#delete_user) | **delete** /v1/users/{id} | Delete a user.
*UsersApi* | [**get_user**](docs/apis/tags/UsersApi.md#get_user) | **get** /v1/users/{id} | Get a single user.
*UsersApi* | [**list_user**](docs/apis/tags/UsersApi.md#list_user) | **get** /v1/users | List all users.
*UsersApi* | [**store_user**](docs/apis/tags/UsersApi.md#store_user) | **post** /v1/users | Store a new user
*UsersApi* | [**update_user**](docs/apis/tags/UsersApi.md#update_user) | **put** /v1/users/{id} | Update an existing user&#x27;s information.
*WebhooksApi* | [**delete_webhook**](docs/apis/tags/WebhooksApi.md#delete_webhook) | **delete** /v1/webhooks/{id} | Delete a webhook.
*WebhooksApi* | [**delete_webhook_message**](docs/apis/tags/WebhooksApi.md#delete_webhook_message) | **delete** /v1/webhooks/{id}/messages/{messageId} | Delete a webhook message.
*WebhooksApi* | [**delete_webhook_message_attempt**](docs/apis/tags/WebhooksApi.md#delete_webhook_message_attempt) | **delete** /v1/webhooks/{id}/messages/{messageId}/attempts/{attemptId} | Delete a webhook attempt.
*WebhooksApi* | [**get_single_webhook_message**](docs/apis/tags/WebhooksApi.md#get_single_webhook_message) | **get** /v1/webhooks/{id}/messages/{messageId} | Get a single message from a webhook.
*WebhooksApi* | [**get_single_webhook_message_attempt**](docs/apis/tags/WebhooksApi.md#get_single_webhook_message_attempt) | **get** /v1/webhooks/{id}/messages/{messageId}/attempts/{attemptId} | Get a single failed attempt from a single webhook message.
*WebhooksApi* | [**get_webhook**](docs/apis/tags/WebhooksApi.md#get_webhook) | **get** /v1/webhooks/{id} | Get a single webhook.
*WebhooksApi* | [**get_webhook_message_attempts**](docs/apis/tags/WebhooksApi.md#get_webhook_message_attempts) | **get** /v1/webhooks/{id}/messages/{messageId}/attempts | Get all the failed attempts of a single webhook message.
*WebhooksApi* | [**get_webhook_messages**](docs/apis/tags/WebhooksApi.md#get_webhook_messages) | **get** /v1/webhooks/{id}/messages | Get all the messages of a single webhook.
*WebhooksApi* | [**list_webhook**](docs/apis/tags/WebhooksApi.md#list_webhook) | **get** /v1/webhooks | List all webhooks.
*WebhooksApi* | [**store_webhook**](docs/apis/tags/WebhooksApi.md#store_webhook) | **post** /v1/webhooks | Store a new webhook
*WebhooksApi* | [**submit_webook**](docs/apis/tags/WebhooksApi.md#submit_webook) | **post** /v1/webhooks/{id}/submit | Submit messages for a webhook.
*WebhooksApi* | [**update_webhook**](docs/apis/tags/WebhooksApi.md#update_webhook) | **put** /v1/webhooks/{id} | Update existing webhook.

## Documentation For Models

 - [Account](docs/models/Account.md)
 - [AccountArray](docs/models/AccountArray.md)
 - [AccountRead](docs/models/AccountRead.md)
 - [AccountRoleProperty](docs/models/AccountRoleProperty.md)
 - [AccountSearchFieldFilter](docs/models/AccountSearchFieldFilter.md)
 - [AccountSingle](docs/models/AccountSingle.md)
 - [AccountStore](docs/models/AccountStore.md)
 - [AccountTypeFilter](docs/models/AccountTypeFilter.md)
 - [AccountTypeProperty](docs/models/AccountTypeProperty.md)
 - [AccountUpdate](docs/models/AccountUpdate.md)
 - [AttachableType](docs/models/AttachableType.md)
 - [Attachment](docs/models/Attachment.md)
 - [AttachmentArray](docs/models/AttachmentArray.md)
 - [AttachmentRead](docs/models/AttachmentRead.md)
 - [AttachmentSingle](docs/models/AttachmentSingle.md)
 - [AttachmentStore](docs/models/AttachmentStore.md)
 - [AttachmentUpdate](docs/models/AttachmentUpdate.md)
 - [AutoBudgetPeriod](docs/models/AutoBudgetPeriod.md)
 - [AutoBudgetType](docs/models/AutoBudgetType.md)
 - [AutocompleteAccount](docs/models/AutocompleteAccount.md)
 - [AutocompleteAccountArray](docs/models/AutocompleteAccountArray.md)
 - [AutocompleteBill](docs/models/AutocompleteBill.md)
 - [AutocompleteBillArray](docs/models/AutocompleteBillArray.md)
 - [AutocompleteBudget](docs/models/AutocompleteBudget.md)
 - [AutocompleteBudgetArray](docs/models/AutocompleteBudgetArray.md)
 - [AutocompleteCategory](docs/models/AutocompleteCategory.md)
 - [AutocompleteCategoryArray](docs/models/AutocompleteCategoryArray.md)
 - [AutocompleteCurrency](docs/models/AutocompleteCurrency.md)
 - [AutocompleteCurrencyArray](docs/models/AutocompleteCurrencyArray.md)
 - [AutocompleteCurrencyCode](docs/models/AutocompleteCurrencyCode.md)
 - [AutocompleteCurrencyCodeArray](docs/models/AutocompleteCurrencyCodeArray.md)
 - [AutocompleteObjectGroup](docs/models/AutocompleteObjectGroup.md)
 - [AutocompleteObjectGroupArray](docs/models/AutocompleteObjectGroupArray.md)
 - [AutocompletePiggy](docs/models/AutocompletePiggy.md)
 - [AutocompletePiggyArray](docs/models/AutocompletePiggyArray.md)
 - [AutocompletePiggyBalance](docs/models/AutocompletePiggyBalance.md)
 - [AutocompletePiggyBalanceArray](docs/models/AutocompletePiggyBalanceArray.md)
 - [AutocompleteRecurrence](docs/models/AutocompleteRecurrence.md)
 - [AutocompleteRecurrenceArray](docs/models/AutocompleteRecurrenceArray.md)
 - [AutocompleteRule](docs/models/AutocompleteRule.md)
 - [AutocompleteRuleArray](docs/models/AutocompleteRuleArray.md)
 - [AutocompleteRuleGroup](docs/models/AutocompleteRuleGroup.md)
 - [AutocompleteRuleGroupArray](docs/models/AutocompleteRuleGroupArray.md)
 - [AutocompleteTag](docs/models/AutocompleteTag.md)
 - [AutocompleteTagArray](docs/models/AutocompleteTagArray.md)
 - [AutocompleteTransaction](docs/models/AutocompleteTransaction.md)
 - [AutocompleteTransactionArray](docs/models/AutocompleteTransactionArray.md)
 - [AutocompleteTransactionID](docs/models/AutocompleteTransactionID.md)
 - [AutocompleteTransactionIDArray](docs/models/AutocompleteTransactionIDArray.md)
 - [AutocompleteTransactionType](docs/models/AutocompleteTransactionType.md)
 - [AutocompleteTransactionTypeArray](docs/models/AutocompleteTransactionTypeArray.md)
 - [AvailableBudget](docs/models/AvailableBudget.md)
 - [AvailableBudgetArray](docs/models/AvailableBudgetArray.md)
 - [AvailableBudgetRead](docs/models/AvailableBudgetRead.md)
 - [AvailableBudgetSingle](docs/models/AvailableBudgetSingle.md)
 - [AvailableBudgetStore](docs/models/AvailableBudgetStore.md)
 - [AvailableBudgetUpdate](docs/models/AvailableBudgetUpdate.md)
 - [BadRequest](docs/models/BadRequest.md)
 - [BasicSummary](docs/models/BasicSummary.md)
 - [BasicSummaryEntry](docs/models/BasicSummaryEntry.md)
 - [Bill](docs/models/Bill.md)
 - [BillArray](docs/models/BillArray.md)
 - [BillRead](docs/models/BillRead.md)
 - [BillRepeatFrequency](docs/models/BillRepeatFrequency.md)
 - [BillSingle](docs/models/BillSingle.md)
 - [BillStore](docs/models/BillStore.md)
 - [BillUpdate](docs/models/BillUpdate.md)
 - [Budget](docs/models/Budget.md)
 - [BudgetArray](docs/models/BudgetArray.md)
 - [BudgetLimit](docs/models/BudgetLimit.md)
 - [BudgetLimitArray](docs/models/BudgetLimitArray.md)
 - [BudgetLimitRead](docs/models/BudgetLimitRead.md)
 - [BudgetLimitSingle](docs/models/BudgetLimitSingle.md)
 - [BudgetLimitStore](docs/models/BudgetLimitStore.md)
 - [BudgetRead](docs/models/BudgetRead.md)
 - [BudgetSingle](docs/models/BudgetSingle.md)
 - [BudgetSpent](docs/models/BudgetSpent.md)
 - [BudgetStore](docs/models/BudgetStore.md)
 - [BudgetUpdate](docs/models/BudgetUpdate.md)
 - [Category](docs/models/Category.md)
 - [CategoryArray](docs/models/CategoryArray.md)
 - [CategoryEarned](docs/models/CategoryEarned.md)
 - [CategoryRead](docs/models/CategoryRead.md)
 - [CategorySingle](docs/models/CategorySingle.md)
 - [CategorySpent](docs/models/CategorySpent.md)
 - [CategoryStore](docs/models/CategoryStore.md)
 - [CategoryUpdate](docs/models/CategoryUpdate.md)
 - [ChartDataPoint](docs/models/ChartDataPoint.md)
 - [ChartDataSet](docs/models/ChartDataSet.md)
 - [ChartLine](docs/models/ChartLine.md)
 - [ConfigValueFilter](docs/models/ConfigValueFilter.md)
 - [ConfigValueUpdateFilter](docs/models/ConfigValueUpdateFilter.md)
 - [Configuration](docs/models/Configuration.md)
 - [ConfigurationArray](docs/models/ConfigurationArray.md)
 - [ConfigurationSingle](docs/models/ConfigurationSingle.md)
 - [ConfigurationUpdate](docs/models/ConfigurationUpdate.md)
 - [CreditCardType](docs/models/CreditCardType.md)
 - [CronResult](docs/models/CronResult.md)
 - [CronResultRow](docs/models/CronResultRow.md)
 - [Currency](docs/models/Currency.md)
 - [CurrencyArray](docs/models/CurrencyArray.md)
 - [CurrencyRead](docs/models/CurrencyRead.md)
 - [CurrencySingle](docs/models/CurrencySingle.md)
 - [CurrencyStore](docs/models/CurrencyStore.md)
 - [CurrencyUpdate](docs/models/CurrencyUpdate.md)
 - [DataDestroyObject](docs/models/DataDestroyObject.md)
 - [ExportFileFilter](docs/models/ExportFileFilter.md)
 - [InsightGroup](docs/models/InsightGroup.md)
 - [InsightGroupEntry](docs/models/InsightGroupEntry.md)
 - [InsightTotal](docs/models/InsightTotal.md)
 - [InsightTotalEntry](docs/models/InsightTotalEntry.md)
 - [InsightTransfer](docs/models/InsightTransfer.md)
 - [InsightTransferEntry](docs/models/InsightTransferEntry.md)
 - [InterestPeriod](docs/models/InterestPeriod.md)
 - [InternalException](docs/models/InternalException.md)
 - [LiabilityDirection](docs/models/LiabilityDirection.md)
 - [LiabilityType](docs/models/LiabilityType.md)
 - [LinkType](docs/models/LinkType.md)
 - [LinkTypeArray](docs/models/LinkTypeArray.md)
 - [LinkTypeRead](docs/models/LinkTypeRead.md)
 - [LinkTypeSingle](docs/models/LinkTypeSingle.md)
 - [LinkTypeStore](docs/models/LinkTypeStore.md)
 - [LinkTypeUpdate](docs/models/LinkTypeUpdate.md)
 - [Meta](docs/models/Meta.md)
 - [NotFound](docs/models/NotFound.md)
 - [ObjectGroup](docs/models/ObjectGroup.md)
 - [ObjectGroupArray](docs/models/ObjectGroupArray.md)
 - [ObjectGroupRead](docs/models/ObjectGroupRead.md)
 - [ObjectGroupSingle](docs/models/ObjectGroupSingle.md)
 - [ObjectGroupUpdate](docs/models/ObjectGroupUpdate.md)
 - [ObjectLink](docs/models/ObjectLink.md)
 - [PageLink](docs/models/PageLink.md)
 - [PiggyBank](docs/models/PiggyBank.md)
 - [PiggyBankArray](docs/models/PiggyBankArray.md)
 - [PiggyBankEvent](docs/models/PiggyBankEvent.md)
 - [PiggyBankEventArray](docs/models/PiggyBankEventArray.md)
 - [PiggyBankEventRead](docs/models/PiggyBankEventRead.md)
 - [PiggyBankRead](docs/models/PiggyBankRead.md)
 - [PiggyBankSingle](docs/models/PiggyBankSingle.md)
 - [PiggyBankStore](docs/models/PiggyBankStore.md)
 - [PiggyBankUpdate](docs/models/PiggyBankUpdate.md)
 - [PolymorphicProperty](docs/models/PolymorphicProperty.md)
 - [Preference](docs/models/Preference.md)
 - [PreferenceArray](docs/models/PreferenceArray.md)
 - [PreferenceRead](docs/models/PreferenceRead.md)
 - [PreferenceSingle](docs/models/PreferenceSingle.md)
 - [PreferenceUpdate](docs/models/PreferenceUpdate.md)
 - [Recurrence](docs/models/Recurrence.md)
 - [RecurrenceArray](docs/models/RecurrenceArray.md)
 - [RecurrenceRead](docs/models/RecurrenceRead.md)
 - [RecurrenceRepetition](docs/models/RecurrenceRepetition.md)
 - [RecurrenceRepetitionStore](docs/models/RecurrenceRepetitionStore.md)
 - [RecurrenceRepetitionType](docs/models/RecurrenceRepetitionType.md)
 - [RecurrenceRepetitionUpdate](docs/models/RecurrenceRepetitionUpdate.md)
 - [RecurrenceSingle](docs/models/RecurrenceSingle.md)
 - [RecurrenceStore](docs/models/RecurrenceStore.md)
 - [RecurrenceTransaction](docs/models/RecurrenceTransaction.md)
 - [RecurrenceTransactionStore](docs/models/RecurrenceTransactionStore.md)
 - [RecurrenceTransactionType](docs/models/RecurrenceTransactionType.md)
 - [RecurrenceTransactionUpdate](docs/models/RecurrenceTransactionUpdate.md)
 - [RecurrenceUpdate](docs/models/RecurrenceUpdate.md)
 - [Rule](docs/models/Rule.md)
 - [RuleAction](docs/models/RuleAction.md)
 - [RuleActionKeyword](docs/models/RuleActionKeyword.md)
 - [RuleActionStore](docs/models/RuleActionStore.md)
 - [RuleActionUpdate](docs/models/RuleActionUpdate.md)
 - [RuleArray](docs/models/RuleArray.md)
 - [RuleGroup](docs/models/RuleGroup.md)
 - [RuleGroupArray](docs/models/RuleGroupArray.md)
 - [RuleGroupRead](docs/models/RuleGroupRead.md)
 - [RuleGroupSingle](docs/models/RuleGroupSingle.md)
 - [RuleGroupStore](docs/models/RuleGroupStore.md)
 - [RuleGroupUpdate](docs/models/RuleGroupUpdate.md)
 - [RuleRead](docs/models/RuleRead.md)
 - [RuleSingle](docs/models/RuleSingle.md)
 - [RuleStore](docs/models/RuleStore.md)
 - [RuleTrigger](docs/models/RuleTrigger.md)
 - [RuleTriggerKeyword](docs/models/RuleTriggerKeyword.md)
 - [RuleTriggerStore](docs/models/RuleTriggerStore.md)
 - [RuleTriggerType](docs/models/RuleTriggerType.md)
 - [RuleTriggerUpdate](docs/models/RuleTriggerUpdate.md)
 - [RuleUpdate](docs/models/RuleUpdate.md)
 - [ShortAccountTypeProperty](docs/models/ShortAccountTypeProperty.md)
 - [StringArray](docs/models/StringArray.md)
 - [StringArrayItem](docs/models/StringArrayItem.md)
 - [SystemInfo](docs/models/SystemInfo.md)
 - [TagArray](docs/models/TagArray.md)
 - [TagModel](docs/models/TagModel.md)
 - [TagModelStore](docs/models/TagModelStore.md)
 - [TagModelUpdate](docs/models/TagModelUpdate.md)
 - [TagRead](docs/models/TagRead.md)
 - [TagSingle](docs/models/TagSingle.md)
 - [Transaction](docs/models/Transaction.md)
 - [TransactionArray](docs/models/TransactionArray.md)
 - [TransactionLink](docs/models/TransactionLink.md)
 - [TransactionLinkArray](docs/models/TransactionLinkArray.md)
 - [TransactionLinkRead](docs/models/TransactionLinkRead.md)
 - [TransactionLinkSingle](docs/models/TransactionLinkSingle.md)
 - [TransactionLinkStore](docs/models/TransactionLinkStore.md)
 - [TransactionLinkUpdate](docs/models/TransactionLinkUpdate.md)
 - [TransactionRead](docs/models/TransactionRead.md)
 - [TransactionSingle](docs/models/TransactionSingle.md)
 - [TransactionSplit](docs/models/TransactionSplit.md)
 - [TransactionSplitStore](docs/models/TransactionSplitStore.md)
 - [TransactionSplitUpdate](docs/models/TransactionSplitUpdate.md)
 - [TransactionStore](docs/models/TransactionStore.md)
 - [TransactionTypeFilter](docs/models/TransactionTypeFilter.md)
 - [TransactionTypeProperty](docs/models/TransactionTypeProperty.md)
 - [TransactionUpdate](docs/models/TransactionUpdate.md)
 - [Unauthenticated](docs/models/Unauthenticated.md)
 - [User](docs/models/User.md)
 - [UserArray](docs/models/UserArray.md)
 - [UserBlockedCodeProperty](docs/models/UserBlockedCodeProperty.md)
 - [UserRead](docs/models/UserRead.md)
 - [UserRoleProperty](docs/models/UserRoleProperty.md)
 - [UserSingle](docs/models/UserSingle.md)
 - [ValidationError](docs/models/ValidationError.md)
 - [Webhook](docs/models/Webhook.md)
 - [WebhookArray](docs/models/WebhookArray.md)
 - [WebhookAttempt](docs/models/WebhookAttempt.md)
 - [WebhookAttemptArray](docs/models/WebhookAttemptArray.md)
 - [WebhookAttemptRead](docs/models/WebhookAttemptRead.md)
 - [WebhookAttemptSingle](docs/models/WebhookAttemptSingle.md)
 - [WebhookDelivery](docs/models/WebhookDelivery.md)
 - [WebhookMessage](docs/models/WebhookMessage.md)
 - [WebhookMessageArray](docs/models/WebhookMessageArray.md)
 - [WebhookMessageRead](docs/models/WebhookMessageRead.md)
 - [WebhookMessageSingle](docs/models/WebhookMessageSingle.md)
 - [WebhookRead](docs/models/WebhookRead.md)
 - [WebhookResponse](docs/models/WebhookResponse.md)
 - [WebhookSingle](docs/models/WebhookSingle.md)
 - [WebhookStore](docs/models/WebhookStore.md)
 - [WebhookTrigger](docs/models/WebhookTrigger.md)
 - [WebhookUpdate](docs/models/WebhookUpdate.md)

## Documentation For Authorization

Authentication schemes defined for the API:
<a id="firefly_iii_auth"></a>
### firefly_iii_auth

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://demo.firefly-iii.org/oauth/authorize
- **Scopes**: N/A

<a id="local_bearer_auth"></a>
### local_bearer_auth

- **Type**: Bearer authentication


## Author

ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com
ms32035@gmail.com

## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in firefly_iii_client.apis and firefly_iii_client.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from firefly_iii_client.apis.default_api import DefaultApi`
- `from firefly_iii_client.model.pet import Pet`

Solution 1:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import firefly_iii_client
from firefly_iii_client.apis import *
from firefly_iii_client.models import *
```
